Module module
pam
0.3.0
Module module
Module Items
Structs
Traits
Type Aliases
In crate pam
pam
Module
module
Functions for use in pam modules.
Structs

PamHandle
Opaque type, used as a pointer when making pam API calls.
Traits

PamHooks
Provides functions that are invoked by the entrypoints generated by the
pam_hooks!
macro
.
Type Aliases

PamResult